import * as Core from 'cloudflare/core';
import { APIResource } from 'cloudflare/resource';
import * as GRETunnelsAPI from 'cloudflare/resources/magic-transit/gre-tunnels';
import * as MagicTransitAPI from 'cloudflare/resources/magic-transit/magic-transit';
export declare class GRETunnels extends APIResource {
    /**
     * Creates new GRE tunnels. Use `?validate_only=true` as an optional query
     * parameter to only run validation without persisting changes.
     */
    create(params: GRETunnelCreateParams, options?: Core.RequestOptions): Core.APIPromise<GRETunnelCreateResponse>;
    /**
     * Updates a specific GRE tunnel. Use `?validate_only=true` as an optional query
     * parameter to only run validation without persisting changes.
     */
    update(tunnelIdentifier: string, params: GRETunnelUpdateParams, options?: Core.RequestOptions): Core.APIPromise<GRETunnelUpdateResponse>;
    /**
     * Lists GRE tunnels associated with an account.
     */
    list(params: GRETunnelListParams, options?: Core.RequestOptions): Core.APIPromise<GRETunnelListResponse>;
    /**
     * Disables and removes a specific static GRE tunnel. Use `?validate_only=true` as
     * an optional query parameter to only run validation without persisting changes.
     */
    delete(tunnelIdentifier: string, params: GRETunnelDeleteParams, options?: Core.RequestOptions): Core.APIPromise<GRETunnelDeleteResponse>;
    /**
     * Lists informtion for a specific GRE tunnel.
     */
    get(tunnelIdentifier: string, params: GRETunnelGetParams, options?: Core.RequestOptions): Core.APIPromise<GRETunnelGetResponse>;
}
export interface GRETunnelCreateResponse {
    gre_tunnels?: Array<GRETunnelCreateResponse.GRETunnel>;
}
export declare namespace GRETunnelCreateResponse {
    interface GRETunnel {
        /**
         * The IP address assigned to the Cloudflare side of the GRE tunnel.
         */
        cloudflare_gre_endpoint: string;
        /**
         * The IP address assigned to the customer side of the GRE tunnel.
         */
        customer_gre_endpoint: string;
        /**
         * A 31-bit prefix (/31 in CIDR notation) supporting two hosts, one for each side
         * of the tunnel. Select the subnet from the following private IP space:
         * 10.0.0.0–10.255.255.255, 172.16.0.0–172.31.255.255, 192.168.0.0–192.168.255.255.
         */
        interface_address: string;
        /**
         * The name of the tunnel. The name cannot contain spaces or special characters,
         * must be 15 characters or less, and cannot share a name with another GRE tunnel.
         */
        name: string;
        /**
         * Tunnel identifier tag.
         */
        id?: string;
        /**
         * The date and time the tunnel was created.
         */
        created_on?: string;
        /**
         * An optional description of the GRE tunnel.
         */
        description?: string;
        health_check?: MagicTransitAPI.HealthCheck;
        /**
         * The date and time the tunnel was last modified.
         */
        modified_on?: string;
        /**
         * Maximum Transmission Unit (MTU) in bytes for the GRE tunnel. The minimum value
         * is 576.
         */
        mtu?: number;
        /**
         * Time To Live (TTL) in number of hops of the GRE tunnel.
         */
        ttl?: number;
    }
}
export interface GRETunnelUpdateResponse {
    modified?: boolean;
    modified_gre_tunnel?: unknown;
}
export interface GRETunnelListResponse {
    gre_tunnels?: Array<GRETunnelListResponse.GRETunnel>;
}
export declare namespace GRETunnelListResponse {
    interface GRETunnel {
        /**
         * The IP address assigned to the Cloudflare side of the GRE tunnel.
         */
        cloudflare_gre_endpoint: string;
        /**
         * The IP address assigned to the customer side of the GRE tunnel.
         */
        customer_gre_endpoint: string;
        /**
         * A 31-bit prefix (/31 in CIDR notation) supporting two hosts, one for each side
         * of the tunnel. Select the subnet from the following private IP space:
         * 10.0.0.0–10.255.255.255, 172.16.0.0–172.31.255.255, 192.168.0.0–192.168.255.255.
         */
        interface_address: string;
        /**
         * The name of the tunnel. The name cannot contain spaces or special characters,
         * must be 15 characters or less, and cannot share a name with another GRE tunnel.
         */
        name: string;
        /**
         * Tunnel identifier tag.
         */
        id?: string;
        /**
         * The date and time the tunnel was created.
         */
        created_on?: string;
        /**
         * An optional description of the GRE tunnel.
         */
        description?: string;
        health_check?: MagicTransitAPI.HealthCheck;
        /**
         * The date and time the tunnel was last modified.
         */
        modified_on?: string;
        /**
         * Maximum Transmission Unit (MTU) in bytes for the GRE tunnel. The minimum value
         * is 576.
         */
        mtu?: number;
        /**
         * Time To Live (TTL) in number of hops of the GRE tunnel.
         */
        ttl?: number;
    }
}
export interface GRETunnelDeleteResponse {
    deleted?: boolean;
    deleted_gre_tunnel?: unknown;
}
export interface GRETunnelGetResponse {
    gre_tunnel?: unknown;
}
export interface GRETunnelCreateParams {
    /**
     * Path param: Identifier
     */
    account_id: string;
    /**
     * Body param:
     */
    body: unknown;
}
export interface GRETunnelUpdateParams {
    /**
     * Path param: Identifier
     */
    account_id: string;
    /**
     * Body param: The IP address assigned to the Cloudflare side of the GRE tunnel.
     */
    cloudflare_gre_endpoint: string;
    /**
     * Body param: The IP address assigned to the customer side of the GRE tunnel.
     */
    customer_gre_endpoint: string;
    /**
     * Body param: A 31-bit prefix (/31 in CIDR notation) supporting two hosts, one for
     * each side of the tunnel. Select the subnet from the following private IP space:
     * 10.0.0.0–10.255.255.255, 172.16.0.0–172.31.255.255, 192.168.0.0–192.168.255.255.
     */
    interface_address: string;
    /**
     * Body param: The name of the tunnel. The name cannot contain spaces or special
     * characters, must be 15 characters or less, and cannot share a name with another
     * GRE tunnel.
     */
    name: string;
    /**
     * Body param: An optional description of the GRE tunnel.
     */
    description?: string;
    /**
     * Body param:
     */
    health_check?: MagicTransitAPI.HealthCheck;
    /**
     * Body param: Maximum Transmission Unit (MTU) in bytes for the GRE tunnel. The
     * minimum value is 576.
     */
    mtu?: number;
    /**
     * Body param: Time To Live (TTL) in number of hops of the GRE tunnel.
     */
    ttl?: number;
}
export interface GRETunnelListParams {
    /**
     * Identifier
     */
    account_id: string;
}
export interface GRETunnelDeleteParams {
    /**
     * Path param: Identifier
     */
    account_id: string;
    /**
     * Body param:
     */
    body: unknown;
}
export interface GRETunnelGetParams {
    /**
     * Identifier
     */
    account_id: string;
}
export declare namespace GRETunnels {
    export import GRETunnelCreateResponse = GRETunnelsAPI.GRETunnelCreateResponse;
    export import GRETunnelUpdateResponse = GRETunnelsAPI.GRETunnelUpdateResponse;
    export import GRETunnelListResponse = GRETunnelsAPI.GRETunnelListResponse;
    export import GRETunnelDeleteResponse = GRETunnelsAPI.GRETunnelDeleteResponse;
    export import GRETunnelGetResponse = GRETunnelsAPI.GRETunnelGetResponse;
    export import GRETunnelCreateParams = GRETunnelsAPI.GRETunnelCreateParams;
    export import GRETunnelUpdateParams = GRETunnelsAPI.GRETunnelUpdateParams;
    export import GRETunnelListParams = GRETunnelsAPI.GRETunnelListParams;
    export import GRETunnelDeleteParams = GRETunnelsAPI.GRETunnelDeleteParams;
    export import GRETunnelGetParams = GRETunnelsAPI.GRETunnelGetParams;
}
//# sourceMappingURL=gre-tunnels.d.ts.map